==> groupoffice-6.1.80.txz: usr/local/www/groupoffice6/modules/tickets/language/nl.php <==
<?php


$l['name']='Tickets';
$l['description']='Support ticket systeem';
$lang['link_type'][20]=$l['ticket_status']='Ticket status';
$l['ticket_statuses']='Ticket statuses';
$l['item']='Item';
$l['items']='Items';
$l['language']='Taal';
$l['languages']='Talen';
$l['sent']='Verzonden';
$l['accepted']='Geaccepteerd';
$l['lost']='Verloren';
$l['none']='Geen';
$l['default']='Standaard';
$l['no_email_template']='Geen e-mail sjabloon opgegeven!';
$l['invald_email']='Onjuist e-mail adres';
$l['sendout']='Verstuur commentaar naar de contactpersoon';
$l['issendout']='Contactpersoon bericht';
$l['priority_level'][0]='Laag';
$l['priority_level'][1]='Normaal';
$l['priority_level'][2]='Hoog';
$l['status_closed']='Gesloten';
$l['ticket_claim_error']='Ticket is geclaimed door ';
$l['ticket_assigned_by']='Toegewezen door';
$l['ticket_updated_by']='Aangepast door';
$l['ticket_action']['responded_by']='Gereageerd door';
$l['subject']='Onderwerp';
$l['question_issue']='Vraag / Probleem';
$l['send']='Verstuur';
$l['new_message']='Nieuw bericht';
$l['status_change']='Status is veranderd naar';
$l['mtime']='Gewijzigd op';
$l['ctime']='Gemaakt op';
$l['data']='Gegevens';
$l['page']='Pagina';
$l['view_ticket']='Bekijk Ticket';
$l['new_ticket']='Nieuw Ticket';
$l['deleted_user']='Verwijderde gebruiker';
$l['template_default_name']='Standaard reactie';
$l['template_default_content']='Beste meneer/mevrouw,
Bedankt voor uw reactie.
{MESSAGE}
Reageer aub niet op deze email. Om te reageren dient u naar de volgende pagina te gaan:
{LINK}
Met vriendelijke groet,
{NAME}.';
$l['template_created_by_client_name']='Standaard aanmaken ticket door klant';
$l['template_created_by_client_content']='Beste meneer/mevrouw,
We hebben uw vraag ontvangen en er is een ticket aangemaakt.
Wij zullen zo spoedig mogelijk contact met u opnemen.
Hieronder ziet u uw vraag terug:
---------------------------------------------------------------------------
{MESSAGE}
---------------------------------------------------------------------------
Reageer aub niet op deze email. Om te reageren dient u naar de volgende pagina te gaan:
{LINK}
Met vriendelijke groet,
{NAME}.';
$l['template_created_for_client_name']='Standaard aanmaken ticket voor klant';
$l['template_created_for_client_content']='Beste meneer/mevrouw,
Wij hebben een ticket voor u aangemaakt.
Wij zullen zo spoedig mogelijk contact met u opnemen.
Het ticket gaat over:
---------------------------------------------------------------------------
{MESSAGE}
---------------------------------------------------------------------------
Reageer aub niet op deze email. Om te reageren dient u naar de volgende pagina te gaan:
{LINK}
Met vriendelijke groet,
{NAME}.';
$l['example_type1']='Techniek';
$l['example_type2']='Verkoop';
$l['example_status1']='In behandeling';
$l['example_status2']='Niet opgelost';
$l['all_types']='Alle types';
$l['viewticketTitle']='Klanten | Ticket Overzicht';
$l['createticketTitle']='Klanten | Nieuw ticket';
$l['period']='Periode';
$l['invoiceCreated']='Factuur aangemaakt';
$l['invoicesCreated']='%s factu(u)r(en) aangemaakt';
$l['number']='Nummer';
$l['newTicketSubject']='Ticket in type %s aangemaakt door %s';
$l['bill_item_template']="{date} #{number} tarief: {rate_name}\n{subject}";
$l['no_read_access']="Klant heeft geen leesrechten tot type";
$l['incomplete_delete']='U heeft niet voldoende rechten om alle geselecteerde tickets te verwijderen';
$l['strAutomaticClosed'] = 'Deze ticket is automatisch gesloten, omdat de klant niet binnen {expire_days} dagen heeft gereageerd.';
$l['january'] = 'Jan';
$l['february'] = 'Feb';
$l['march'] = 'Mrt';
$l['april'] = 'Apr';
$l['may'] = 'Mei';
$l['june'] = 'Jun';
$l['july'] = 'Jul';
$l['august'] = 'Aug';
$l['september'] = 'Sep';
$l['october'] = 'Okt';
$l['november'] = 'Nov';
$l['december'] = 'Dec';
$l['total'] = 'Totaal';
$l['run_time'] = 'Doorlooptijd';
$l['invalid_company_id'] = 'Neemt u a.u.b. contact met de beheerder: ongeldige company id gegeven voor het ophalen van de bedrijfstarieven. Specificeert u a.u.b. ook wat vlak hiervoor gebeurde binnen uw {product_name} sessie.';
$l['rateSaveErrorOnName'] = 'Probleem bij het opslaan van tarief ';
$l['reportToAdmin'] = 'Geeft u melding a.u.b. bij uw {product_name}beheerder, en dit probleem wordt zo spoedig mogelijk opgelost.';$l["tickets"]='Tickets';
$l["type"]="Type";
$l["types"]="Types";
$l["status"]="Status";
$l["statuses"]="Statussen";
$l["ticketId"]="Ticket ID";
$l["createTicket"]='Aanmaken ticket';
$l["editTicket"]='Wijzigen ticket';
$l["reopen"]='Heropen';
$l["reopenTooltip"]='Heropen ticket';
$l["claim"]='Claim';
$l["unclaim"]='Unclaim';
$l["claimTooltip"]='Claim ticket';
$l["unclaimTooltip"]='Unclaim ticket';
$l["closeTicket"]='Sluit ticket';
$l["ticketDetails"]='Ticket overzicht';
$l["agent"]='Verantwoordelijke';
$l["contact"]='Contactpersoon';
$l["unknownContact"]='<onbekend>';
$l["message"]='Bericht';
$l["messages"]='Berichten';
$l["editMessage"]='Wijzig bericht';
$l["newMessage"]='Nieuw bericht';
$l["statusChange"]='* Status is veranderd naar';
$l["is_note"]='Notitie';
$l["attachments"]='Bijlagen';
$l["changeTicketStatus"]='Verander ticket van status';
$l["notified"]="Bericht verstuurd";
$l["notifyContact"]="Contactpersoon op de hoogte stellen";
$l["notifyContactCheck"]="Contactpersoon op de hoogte stellen standaard aanvinken";
$l["template"]="Sjabloon";
$l["templates"]="Sjablonen";
$l["emailTemplates"]="Email sjablonen";
$l["select_template"]="Gebruik email sjabloon";
$l["priority"]='Prioriteit';
$l["priority_low"]='Laag';
$l["priority_normal"]='Normaal';
$l["priority_high"]='Hoog';
$l["status_open"]='Open';
$l["options"]='Opties';
$l["default_type"]='Standaard type';
$l["default_template"]='Standaard reactie';
$l["auto_reply"]='Aanmaken ticket door klant';
$l["ticket_created_for_client"]='Aanmaken ticket voor klant';
$l["markAsRead"]='Markeren als gelezen';
$l["markAsUnread"]='Markeren als ongelezen';
$l["url"]='URL';
$l["logo"]='Logo';
$l["show_external"]='Toon op externe pagina';
$l["show_from_others"]='Toon tickets van anderen met dit type aan reguliere gebruikers';
$l["showMineOnly"]='Toon alleen mijn tickets';
$l["addTicket"]= 'Ticket toevoegen';
$l["attachFiles"]='Bestanden bijvoegen';
$l["rates"]='Tarieven';
$l["rate"]='Tarief';
$l["amount"]='Bedrag';
$l["rateHours"]='Tarief / uren';
$l["rateTotals"]='Totaal tarieven';
$l["bill"]='Factureer';
$l["toStatus"]='Naar status';
$l["fromStatus"]='Van status';
$l["noRate"]='Geen tarief';
$l["notifyAgents"]='Stuur e-mail naar ticket managers wanneer een nieuw ticket wordt aangemaakt door een bezoeker';
$l["notifyAdmin"]="Stuur ook e-mail naar gebruikers van de groep 'Admins'";
$l["youHaveNewTickets"]='U heeft {new} nieuwe ticket(s)';
$l["messageTemplate"]='Berichtsjabloon';
$l["sendMessage"]='Bericht verzenden';
$l["saveAsNote"]='Opslaan als notitie';
$l["ticketDeleted"]='Ticket bestaat niet meer';
$l["changeTicketsWithoutHoursToo"]='Verander de ticket status ook van tickets zonder geboekte uren';
$l["expireDays"]= 'Aantal dagen voordat door klant onbeantwoorde berichten automatisch worden gesloten. Stel dit in op 0 om dit nooit te laten doen.';
$l["nobody"]= 'Niemand';
$l["ticketGroups"]= 'Ticketgroepen';
$l["ticketGroup"]= 'Ticketgroep';
$l["noAclId"]= 'Het lijkt erop dat er een bestaand model is afgehandeld bij de server, maar met een ongeldig acl_id. Neemt u a.u.b. contact op met uw {product_name} beheerder hierover met kennisgeving van wat er gebeurde voorafgaand aan dit bericht, en dit wordt zo snel mogelijk opgelost.';

$l['groupBy'] = 'Eén factuur per';
$l['company'] = 'Bedrijf';
$l['customerAccount'] = 'Klantaccount';

$l['customSender'] = "Gebruik alternatieve afzender in emails aan klant";
$l['customSenderName'] = "Naam afzender";
$l['customSenderEmail'] = "Emailadres afzender";



$l["ticket"]='Ticket';
$l["customer_message_label"]='Klant bericht op externe pagina';
$l["response_message_label"]='Ticket opgeslagen berichtop externe pagina';
$l['customer_message']='This is our support system. Please enter your contact information and describe your problem.';
$l['response_message']='Thank you for contacting us. We have received your question and created a ticket for you. we will respond as soon as possible. For future reference, your question has been assigned the following ticket number: {TICKET_NUMBER}.';

$l['invoiceErrorStatus']='Foutstatus';
$l['invoiceMissingCompany']="Ticket heeft geen bedrijf voor op de factuur";
$l['nothingToInvoice']="Status verandered door facturatie maar er waren geen uren geboekt.";
$l['useAlternativeUrl']='Gebruik alternatieve URL';
$l['ticketEmail_on_new']='Stuur e-mail bij nieuw ticket';
$l['modifiedTicketSubject']='Ticket in type %s is gewijzigd door %s';
$l['emailToAgent']="Stuur e-mail naar agent wanneer een klant antwoord";
$l["ticketTicket_number"]= "Ticketnummer";
$l["ticketTicket_verifier"]= "Ticket verificatiecode";
$l["ticketPriority"]= "Prioriteit";
$l["ticketStatus_id"]= "Status";
$l["ticketType_id"]= "Type";
$l["ticketUser_id"]= "Gebruiker";
$l["ticketAgent_id"]= "Agent";
$l["ticketContact_id"]= "Contactpersoon";
$l["ticketCompany"]= "Bedrijf";
$l["ticketCompany_id"]= "Bedrijf";
$l["ticketFirst_name"]= "Voornaam";
$l["ticketMiddle_name"]= "Tussenvoegsel";
$l["ticketLast_name"]= "Achternaam";
$l["ticketEmail"]= "E-mail";
$l["ticketPhone"]= "Telefoon";
$l["ticketSubject"]= "Onderwerp";
$l["ticketUnseen"]= "Ongelezen";
$l["ticketGroup_id"]= "Groep";
$l["ticketOrder_id"]= "Order";
$l["invalid_agent"]= "De geselecteerde agent heeft geen toegang tot tickets van dit type";
$l['neverCloseStatus']="Sluit nooit tickets met deze status";

$l['read']='Gelezen';

$l['assignedTo']='Toegewezen aan';

$l['typeGroup'] = "Type groep";
$l['manageGroups'] = "Beheer groepen";
$l['general'] = "Algemeen";

$l['deletePermissionError']='Tickets kunnen alleen verwijderd worden door gerbuikers met beheerrechtenop de ticket module.';

$l['importCaution']='<b>Waarschuwing!</b> Selecteer een IMAP mailbox hieronder om automatisch de e-mail berichten als tickets te importeren. Alle e-mail bericthen worden VERWIJDERD na de import. U moet dus een speciale IMAP account hiervoor gebruiken.';	

$l['solved']='Opgelost';
$l['solvedTickets']='Gesloten tickets per gebruiker';
$l['averageSolvingTime']='Gemiddelde ticket duur';

$l['ccNotificationsTo'] = 'CC notificaties naar';

$l['currentTickets'] = 'Aantal huidige tickets';
$l['unassigned'] = 'Niet toegewezen';
$l['nCurrentTickets'] = 'Aantal huidige tickets';
$l['closedTicketsInMonth'] = 'Gesloten tickets in maand';
$l['byType'] = 'Tickets per type';

$l["changeTicketType"]='Verander tickettype';
$l["type_change"] = 'Type is veranderd naar';

$l['leaveTypeBlankByDefault'] = 'Bij het maken van een nieuwe ticket, doe geen automatische voorselectie van een tickettype';
$l['setAgent'] = 'Verantwoordelijke instellen';

==> groupoffice-6.2.19.txz: usr/local/www/groupoffice6/modules/tickets/language/nl.php <==
<?php


$l['name']='Tickets';
$l['description']='Support ticket systeem';
$lang['link_type'][20]=$l['ticket_status']='Ticket status';
$l['ticket_statuses']='Ticket statuses';
$l['item']='Item';
$l['items']='Items';
$l['language']='Taal';
$l['languages']='Talen';
$l['sent']='Verzonden';
$l['accepted']='Geaccepteerd';
$l['lost']='Verloren';
$l['none']='Geen';
$l['default']='Standaard';
$l['no_email_template']='Geen e-mail sjabloon opgegeven!';
$l['invald_email']='Onjuist e-mail adres';
$l['sendout']='Verstuur commentaar naar de contactpersoon';
$l['issendout']='Contactpersoon bericht';
$l['priority_level'][0]='Laag';
$l['priority_level'][1]='Normaal';
$l['priority_level'][2]='Hoog';
$l['status_closed']='Gesloten';
$l['ticket_claim_error']='Ticket is geclaimed door ';
$l['ticket_assigned_by']='Toegewezen door';
$l['ticket_updated_by']='Aangepast door';
$l['ticket_action']['responded_by']='Gereageerd door';
$l['subject']='Onderwerp';
$l['question_issue']='Vraag / Probleem';
$l['send']='Verstuur';
$l['new_message']='Nieuw bericht';
$l['status_change']='Status is veranderd naar';
$l['mtime']='Gewijzigd op';
$l['ctime']='Gemaakt op';
$l['data']='Gegevens';
$l['page']='Pagina';
$l['view_ticket']='Bekijk Ticket';
$l['new_ticket']='Nieuw Ticket';
$l['deleted_user']='Verwijderde gebruiker';
$l['template_default_name']='Standaard reactie';
$l['template_default_content']='Beste meneer/mevrouw,
Bedankt voor uw reactie.
{MESSAGE}
Reageer aub niet op deze email. Om te reageren dient u naar de volgende pagina te gaan:
{LINK}
Met vriendelijke groet,
{NAME}.';
$l['template_created_by_client_name']='Standaard aanmaken ticket door klant';
$l['template_created_by_client_content']='Beste meneer/mevrouw,
We hebben uw vraag ontvangen en er is een ticket aangemaakt.
Wij zullen zo spoedig mogelijk contact met u opnemen.
Hieronder ziet u uw vraag terug:
---------------------------------------------------------------------------
{MESSAGE}
---------------------------------------------------------------------------
Reageer aub niet op deze email. Om te reageren dient u naar de volgende pagina te gaan:
{LINK}
Met vriendelijke groet,
{NAME}.';
$l['template_created_for_client_name']='Standaard aanmaken ticket voor klant';
$l['template_created_for_client_content']='Beste meneer/mevrouw,
Wij hebben een ticket voor u aangemaakt.
Wij zullen zo spoedig mogelijk contact met u opnemen.
Het ticket gaat over:
---------------------------------------------------------------------------
{MESSAGE}
---------------------------------------------------------------------------
Reageer aub niet op deze email. Om te reageren dient u naar de volgende pagina te gaan:
{LINK}
Met vriendelijke groet,
{NAME}.';
$l['example_type1']='Techniek';
$l['example_type2']='Verkoop';
$l['example_status1']='In behandeling';
$l['example_status2']='Niet opgelost';
$l['all_types']='Alle types';
$l['viewticketTitle']='Klanten | Ticket Overzicht';
$l['createticketTitle']='Klanten | Nieuw ticket';
$l['period']='Periode';
$l['invoiceCreated']='Factuur aangemaakt';
$l['invoicesCreated']='%s factu(u)r(en) aangemaakt';
$l['number']='Nummer';
$l['newTicketSubject']='Ticket in type %s aangemaakt door %s';
$l['bill_item_template']="{date} #{number} tarief: {rate_name}\n{subject}";
$l['no_read_access']="Klant heeft geen leesrechten tot type";
$l['incomplete_delete']='U heeft niet voldoende rechten om alle geselecteerde tickets te verwijderen';
$l['strAutomaticClosed'] = 'Deze ticket is automatisch gesloten, omdat de klant niet binnen {expire_days} dagen heeft gereageerd.';
$l['january'] = 'Jan';
$l['february'] = 'Feb';
$l['march'] = 'Mrt';
$l['april'] = 'Apr';
$l['may'] = 'Mei';
$l['june'] = 'Jun';
$l['july'] = 'Jul';
$l['august'] = 'Aug';
$l['september'] = 'Sep';
$l['october'] = 'Okt';
$l['november'] = 'Nov';
$l['december'] = 'Dec';
$l['total'] = 'Totaal';
$l['run_time'] = 'Doorlooptijd';
$l['invalid_company_id'] = 'Neemt u a.u.b. contact met de beheerder: ongeldige company id gegeven voor het ophalen van de bedrijfstarieven. Specificeert u a.u.b. ook wat vlak hiervoor gebeurde binnen uw {product_name} sessie.';
$l['rateSaveErrorOnName'] = 'Probleem bij het opslaan van tarief ';
$l['reportToAdmin'] = 'Geeft u melding a.u.b. bij uw {product_name}beheerder, en dit probleem wordt zo spoedig mogelijk opgelost.';$l["tickets"]='Tickets';
$l["type"]="Type";
$l["types"]="Types";
$l["status"]="Status";
$l["statuses"]="Statussen";
$l["ticketId"]="Ticket ID";
$l["createTicket"]='Aanmaken ticket';
$l["editTicket"]='Wijzigen ticket';
$l["reopen"]='Heropen';
$l["reopenTooltip"]='Heropen ticket';
$l["claim"]='Claim';
$l["unclaim"]='Unclaim';
$l["claimTooltip"]='Claim ticket';
$l["unclaimTooltip"]='Unclaim ticket';
$l["closeTicket"]='Sluit ticket';
$l["ticketDetails"]='Ticket overzicht';
$l["agent"]='Verantwoordelijke';
$l["contact"]='Contactpersoon';
$l["unknownContact"]='<onbekend>';
$l["message"]='Bericht';
$l["messages"]='Berichten';
$l["editMessage"]='Wijzig bericht';
$l["newMessage"]='Nieuw bericht';
$l["statusChange"]='* Status is veranderd naar';
$l["is_note"]='Notitie';
$l["attachments"]='Bijlagen';
$l["changeTicketStatus"]='Verander ticket van status';
$l["notified"]="Bericht verstuurd";
$l["notifyContact"]="Contactpersoon op de hoogte stellen";
$l["notifyContactCheck"]="Contactpersoon op de hoogte stellen standaard aanvinken";
$l["template"]="Sjabloon";
$l["templates"]="Sjablonen";
$l["emailTemplates"]="Email sjablonen";
$l["select_template"]="Gebruik email sjabloon";
$l["priority"]='Prioriteit';
$l["priority_low"]='Laag';
$l["priority_normal"]='Normaal';
$l["priority_high"]='Hoog';
$l["status_open"]='Open';
$l["options"]='Opties';
$l["default_type"]='Standaard type';
$l["default_template"]='Standaard reactie';
$l["auto_reply"]='Aanmaken ticket door klant';

$l["markAsRead"]='Markeren als gelezen';
$l["markAsUnread"]='Markeren als ongelezen';
$l["url"]='URL';
$l["logo"]='Logo';
$l["show_external"]='Toon op externe pagina';
$l["show_from_others"]='Toon tickets van anderen met dit type aan reguliere gebruikers';
$l["showMineOnly"]='Toon alleen mijn tickets';
$l["addTicket"]= 'Ticket toevoegen';
$l["attachFiles"]='Bestanden bijvoegen';
$l["rates"]='Tarieven';
$l["rate"]='Tarief';
$l["amount"]='Bedrag';
$l["rateHours"]='Tarief / uren';
$l["rateTotals"]='Totaal tarieven';
$l["bill"]='Factureer';
$l["toStatus"]='Naar status';
$l["fromStatus"]='Van status';
$l["noRate"]='Geen tarief';
$l["notifyAgents"]='Stuur e-mail naar ticket managers wanneer een nieuw ticket wordt aangemaakt door een bezoeker';
$l["notifyAdmin"]="Stuur ook e-mail naar gebruikers van de groep 'Admins'";
$l["youHaveNewTickets"]='U heeft {new} nieuwe ticket(s)';
$l["messageTemplate"]='Berichtsjabloon';
$l["sendMessage"]='Bericht verzenden';
$l["saveAsNote"]='Opslaan als notitie';
$l["ticketDeleted"]='Ticket bestaat niet meer';
$l["changeTicketsWithoutHoursToo"]='Verander de ticket status ook van tickets zonder geboekte uren';
$l["expireDays"]= 'Aantal dagen voordat door klant onbeantwoorde berichten automatisch worden gesloten. Stel dit in op 0 om dit nooit te laten doen.';
$l["nobody"]= 'Niemand';
$l["ticketGroups"]= 'Ticketgroepen';
$l["ticketGroup"]= 'Ticketgroep';
$l["noAclId"]= 'Het lijkt erop dat er een bestaand model is afgehandeld bij de server, maar met een ongeldig acl_id. Neemt u a.u.b. contact op met uw {product_name} beheerder hierover met kennisgeving van wat er gebeurde voorafgaand aan dit bericht, en dit wordt zo snel mogelijk opgelost.';

$l['groupBy'] = 'Eén factuur per';
$l['company'] = 'Bedrijf';
$l['customerAccount'] = 'Klantaccount';

$l['customSender'] = "Gebruik alternatieve afzender in emails aan klant";
$l['customSenderName'] = "Naam afzender";
$l['customSenderEmail'] = "Emailadres afzender";



$l["ticket"]='Ticket';
$l["customer_message_label"]='Klant bericht op externe pagina';
$l["response_message_label"]='Ticket opgeslagen berichtop externe pagina';
$l['customer_message']='This is our support system. Please enter your contact information and describe your problem.';
$l['response_message']='Thank you for contacting us. We have received your question and created a ticket for you. we will respond as soon as possible. For future reference, your question has been assigned the following ticket number: {TICKET_NUMBER}.';

$l['invoiceErrorStatus']='Foutstatus';
$l['invoiceMissingCompany']="Ticket heeft geen bedrijf voor op de factuur";
$l['nothingToInvoice']="Status verandered door facturatie maar er waren geen uren geboekt.";
$l['useAlternativeUrl']='Gebruik alternatieve URL';
$l['ticketEmail_on_new']='Stuur e-mail bij nieuw ticket';
$l['modifiedTicketSubject']='Ticket in type %s is gewijzigd door %s';
$l['emailToAgent']="Stuur e-mail naar agent wanneer een klant antwoord";
$l["ticketTicket_number"]= "Ticketnummer";
$l["ticketTicket_verifier"]= "Ticket verificatiecode";
$l["ticketPriority"]= "Prioriteit";
$l["ticketStatus_id"]= "Status";
$l["ticketType_id"]= "Type";
$l["ticketUser_id"]= "Gebruiker";
$l["ticketAgent_id"]= "Agent";
$l["ticketContact_id"]= "Contactpersoon";
$l["ticketCompany"]= "Bedrijf";
$l["ticketCompany_id"]= "Bedrijf";
$l["ticketFirst_name"]= "Voornaam";
$l["ticketMiddle_name"]= "Tussenvoegsel";
$l["ticketLast_name"]= "Achternaam";
$l["ticketEmail"]= "E-mail";
$l["ticketPhone"]= "Telefoon";
$l["ticketSubject"]= "Onderwerp";
$l["ticketUnseen"]= "Ongelezen";
$l["ticketGroup_id"]= "Groep";
$l["ticketOrder_id"]= "Order";
$l["invalid_agent"]= "De geselecteerde agent heeft geen toegang tot tickets van dit type";
$l['neverCloseStatus']="Sluit nooit tickets met deze status";

$l['read']='Gelezen';

$l['assignedTo']='Toegewezen aan';

$l['typeGroup'] = "Type groep";
$l['manageGroups'] = "Beheer groepen";
$l['general'] = "Algemeen";

$l['deletePermissionError']='Tickets kunnen alleen verwijderd worden door gerbuikers met beheerrechtenop de ticket module.';

$l['importCaution']='<b>Waarschuwing!</b> Selecteer een IMAP mailbox hieronder om automatisch de e-mail berichten als tickets te importeren. Alle e-mail bericthen worden VERWIJDERD na de import. U moet dus een speciale IMAP account hiervoor gebruiken.';	

$l['solved']='Opgelost';
$l['solvedTickets']='Gesloten tickets per gebruiker';
$l['averageSolvingTime']='Gemiddelde ticket duur';

$l['ccNotificationsTo'] = 'CC notificaties naar';

$l['currentTickets'] = 'Aantal huidige tickets';
$l['unassigned'] = 'Niet toegewezen';
$l['nCurrentTickets'] = 'Aantal huidige tickets';
$l['closedTicketsInMonth'] = 'Gesloten tickets in maand';
$l['byType'] = 'Tickets per type';

$l["changeTicketType"]='Verander tickettype';
$l["type_change"] = 'Type is veranderd naar';

$l['leaveTypeBlankByDefault'] = 'Bij het maken van een nieuwe ticket, doe geen automatische voorselectie van een tickettype';
$l['setAgent'] = 'Verantwoordelijke instellen';

$l['email notifications'] = 'E-mail Notificaties';
$l['new ticket checkbox'] = 'Stuur e-mail naar klant indien de klant een nieuwe ticket aanmaakt';
$l['assigned checkbox'] = 'Stuur e-mail naar klant als de ticket toegewezen wordt aan een medewerker';
$l['notify agent checkbox'] = 'Stuur e-mail naar medewerker als de klant op de ticket reageert';
$l['enable templates by type'] = 'Gebruik alternatieve e-mail notificaties voor dit type';

$l["ticket_created_for_client"]= 'Gebruik dit sjabloon wanneer een medewerker een ticket aanmaakt voor een klant';
$l["notify_email_by_new_tickit"]= 'Stuur een bericht naar de volgende e-mail adressen wanneer er een nieuw ticket wordt aangemaakt';
$l["email_on_new_msg_body"]= 'E-mail body';

$l["onlyManagerReopenTicket"]="Alleen module managers mogen tickets heropenen";
